@@ -8,7 +8,7 @@ from collections import defaultdict
 import re
 
 from scrapy.item import Item
-from scrapy.selector import HtmlXPathSelector
+from scrapy.selector import Selector
 from scrapy.utils.misc import arg_to_iter, extract_regex
 from scrapy.utils.python import flatten
 from .common import wrap_loader_context
@@ -79,7 +79,11 @@ class ItemLoader(object):
     def get_output_value(self, field_name):
         proc = self.get_output_processor(field_name)
         proc = wrap_loader_context(proc, self.context)
-        return proc(self._values[field_name])
+        try:
+            return proc(self._values[field_name])
+        except Exception as e:
+            raise ValueError("Error with output processor: field=%r value=%r error='%s: %s'" % \
+                (field_name, self._values[field_name], type(e).__name__, str(e)))
 
     def get_collected_values(self, field_name):
         return self._values[field_name]
@@ -112,7 +116,7 @@ class ItemLoader(object):
 
 class XPathItemLoader(ItemLoader):
 
-    default_selector_class = HtmlXPathSelector
+    default_selector_class = Selector
 
     def __init__(self, item=None, selector=None, response=None, **context):
         if selector is None and response is None:
@@ -138,5 +142,4 @@ class XPathItemLoader(ItemLoader):
 
     def _get_values(self, xpaths, **kw):
         xpaths = arg_to_iter(xpaths)
-        return flatten([self.selector.select(xpath).extract() for xpath in xpaths])
-
+        return flatten([self.selector.xpath(xpath).extract() for xpath in xpaths])
